@@ -13,16 +13,21 @@ from pygubu.component.builderobject import (
 )
 
 
+has_tk_version_9 = tk.TkVersion >= 9
+
+
 #
 # ttk widgets
 #
 class TTKWidgetBO(BuilderObject):
     OPTIONS_LABEL = (
+        "compound",
+        "font",
+        "image",
+        "padding",
         "text",
         "textvariable",
         "underline",
-        "image",
-        "compound",
         "width",
     )
     OPTIONS_COMPATIBILITY = ("state",)
@@ -137,6 +142,37 @@ register_widget(
 )
 
 
+_v9_entry_opts = (
+    ("placeholder", "placeholderforeground") if has_tk_version_9 else tuple()
+)
+
+
+class TTKEntry(TTKWidgetBO, EntryBaseBO):
+    OPTIONS_STANDARD = TTKWidgetBO.OPTIONS_STANDARD + ("xscrollcommand",)
+    OPTIONS_SPECIFIC = (
+        "exportselection",
+        "font",
+        "invalidcommand",
+        "justify",
+        "show",
+        "state",
+        "textvariable",
+        "validate",
+        "validatecommand",
+        "width",
+    ) + _v9_entry_opts
+    OPTIONS_CUSTOM = ("text",)
+    class_ = ttk.Entry
+    container = False
+    properties = OPTIONS_STANDARD + OPTIONS_SPECIFIC + OPTIONS_CUSTOM
+    command_properties = ("validatecommand", "invalidcommand", "xscrollcommand")
+
+
+register_widget(
+    "ttk.Entry", TTKEntry, "ttk.Entry", (_("Control & Display"), "ttk")
+)
+
+
 class TTKCombobox(TTKWidgetBO):
     OPTIONS_SPECIFIC = (
         "exportselection",
@@ -151,7 +187,7 @@ class TTKCombobox(TTKWidgetBO):
         "validatecommand",
         "invalidcommand",
         "xscrollcommand",
-    )
+    ) + _v9_entry_opts
     class_ = ttk.Combobox
     container = False
     properties = (
@@ -205,29 +241,10 @@ register_widget(
 )
 
 
-class TTKEntry(TTKWidgetBO, EntryBaseBO):
-    OPTIONS_STANDARD = TTKWidgetBO.OPTIONS_STANDARD + ("xscrollcommand",)
-    OPTIONS_SPECIFIC = (
-        "exportselection",
-        "font",
-        "invalidcommand",
-        "justify",
-        "show",
-        "state",
-        "textvariable",
-        "validate",
-        "validatecommand",
-        "width",
-    )
-    OPTIONS_CUSTOM = ("text",)
-    class_ = ttk.Entry
-    container = False
-    properties = OPTIONS_STANDARD + OPTIONS_SPECIFIC + OPTIONS_CUSTOM
-    command_properties = ("validatecommand", "invalidcommand", "xscrollcommand")
-
-
-register_widget(
-    "ttk.Entry", TTKEntry, "ttk.Entry", (_("Control & Display"), "ttk")
+_v9_pbar_options = (
+    ("anchor", "font", "foreground", "justify", "text", "wraplength")
+    if has_tk_version_9
+    else tuple()
 )
 
 
@@ -239,7 +256,7 @@ class TTKProgressbar(TTKWidgetBO):
         "maximum",
         "value",
         "variable",
-    )  # 'phase' is read-only
+    ) + _v9_pbar_options
     class_ = ttk.Progressbar
     container = False
     properties = TTKWidgetBO.OPTIONS_STANDARD + OPTIONS_SPECIFIC
@@ -347,7 +364,7 @@ class TTKMenubuttonBO(TTKWidgetBO):
     )
     OPTIONS_SPECIFIC = ("direction",)  # 'menu'
     class_ = ttk.Menubutton
-    container = False
+    container = True
     properties = OPTIONS_STANDARD + OPTIONS_SPECIFIC
     allowed_children = ("tk.Menu",)
     maxchildren = 1
@@ -528,7 +545,7 @@ class TTKNotebookTab(TTKWidgetBO):
     def configure(self, target=None):
         pass
 
-    def layout(self, target=None):
+    def layout(self, target=None, *, forget=False):
         pass
 
     def add_child(self, bobject):
@@ -639,7 +656,7 @@ class TTKTreeviewColumnBO(TTKWidgetBO):
     def configure(self, target=None):
         pass
 
-    def layout(self, target=None):
+    def layout(self, target=None, *, forget=False):
         pass
 
     def _connect_command(self, cpname, callback):
@@ -672,14 +689,18 @@ register_widget(
 
 class TTKSpinboxBO(TTKWidgetBO, EntryBaseBO):
     OPTIONS_STANDARD = TTKEntry.OPTIONS_STANDARD
-    OPTIONS_SPECIFIC = TTKEntry.OPTIONS_SPECIFIC + (
-        "from_",
-        "to",
-        "increment",
-        "values",
-        "wrap",
-        "format",
-        "command",
+    OPTIONS_SPECIFIC = (
+        TTKEntry.OPTIONS_SPECIFIC
+        + (
+            "from_",
+            "to",
+            "increment",
+            "values",
+            "wrap",
+            "format",
+            "command",
+        )
+        + _v9_entry_opts
     )
     OPTIONS_CUSTOM = TTKEntry.OPTIONS_CUSTOM
     class_ = None
@@ -735,7 +756,10 @@ class OptionMenuBO(OptionMenuBaseMixin, BuilderObject):
         variable_arg,
         command_arg,
     ):
-        return f"{identifier} = {classname}({master}, {variable_arg}, {value_arg}, *__values, command={command_arg})"
+        return (
+            f"{identifier} = {classname}({master}, {variable_arg},"
+            + f" {value_arg}, *__values, command={command_arg})"
+        )
 
 
 register_widget(
