@@ -85,7 +85,8 @@ class ThemeDefinition:
         self.type = theme_type
 
 
-_colect_styles = True if os.getenv("PYGUBU_DESIGNER_RUNNING") else False
+_colect_styles = bool(os.getenv("PYGUBU_DESIGNER_RUNNING"))
+has_tk_version_9 = tk.TkVersion >= 9
 
 
 class BootstrapThemeBuilder(IThemeBuilder):
@@ -404,6 +405,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
             # Buttons
             self.create_button_style(settings, name)
             self.create_toolbutton_style(settings, name)
+            self.create_outline_button_style(settings, name)
             self.create_outline_menubutton_style(settings, name)
             self.create_outline_toolbutton_style(settings, name)
             self.create_link_button_style(settings, name)
@@ -437,6 +439,8 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
             self.create_table_treeview_style(settings, name)
             # sizegrip
             self.create_sizegrip_style(settings, name)
+            # Floodgauge
+            self.create_floodgauge_style(settings, name)
 
         tfinish = timeit.default_timer() - tstart
         logger.debug("Bootstrap ttk theme build time: %s", tfinish)
@@ -613,8 +617,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
         settings[ttkstyle] = {
             "configure": {"foreground": foreground, "background": background}
         }
-        if colorname:
-            self._register_style(ttkstyle)
+        self._register_style(ttkstyle)
 
     def create_button_style(self, settings, colorname=None):
         STYLE = "TButton"
@@ -751,6 +754,71 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
         if colorname:
             self._register_style(ttkstyle)
 
+    def create_outline_button_style(self, settings, colorname=None):
+        """Create an outline style for the ttk.Button widget."""
+        STYLE = "Outline.TButton"
+
+        disabled_fg = self.colorutil.make_transparent(
+            0.30, self.colors.fg, self.colors.bg
+        )
+
+        if any([colorname is None, not colorname]):
+            ttkstyle = STYLE
+            colorname = PRIMARY
+        else:
+            ttkstyle = f"{colorname}.{STYLE}"
+
+        foreground = self.colors.get_color(colorname)
+        background = self.colors.get_foreground(colorname)
+        foreground_pressed = background
+        bordercolor = foreground
+        pressed = foreground
+        hover = foreground
+
+        settings[ttkstyle] = {
+            "configure": {
+                "foreground": foreground,
+                "background": self.colors.bg,
+                "bordercolor": bordercolor,
+                "darkcolor": self.colors.bg,
+                "lightcolor": self.colors.bg,
+                "relief": tk.RAISED,
+                "focusthickness": 0,
+                "focuscolor": foreground,
+                "padding": (10, 5),
+                "anchor": tk.CENTER,
+            },
+            "map": {
+                "foreground": [
+                    ("disabled", disabled_fg),
+                    ("pressed !disabled", foreground_pressed),
+                    ("hover !disabled", foreground_pressed),
+                ],
+                "background": [
+                    ("pressed !disabled", pressed),
+                    ("hover !disabled", hover),
+                ],
+                "bordercolor": [
+                    ("disabled", disabled_fg),
+                    ("pressed !disabled", pressed),
+                    ("hover !disabled", hover),
+                ],
+                "darkcolor": [
+                    ("pressed !disabled", pressed),
+                    ("hover !disabled", hover),
+                ],
+                "lightcolor": [
+                    ("pressed !disabled", pressed),
+                    ("hover !disabled", hover),
+                ],
+                "focuscolor": [
+                    ("pressed !disabled", foreground_pressed),
+                    ("hover !disabled", foreground_pressed),
+                ],
+            },
+        }
+        self._register_style(ttkstyle)
+
     def create_outline_menubutton_style(self, settings, colorname=None):
         """Create an outline button style for the ttk.Menubutton widget"""
         STYLE = "Outline.TMenubutton"
@@ -817,8 +885,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 ],
             },
         }
-        if colorname:
-            self._register_style(ttkstyle)
+        self._register_style(ttkstyle)
 
     def create_outline_toolbutton_style(self, settings, colorname=None):
         """Create an outline toolbutton style for the ttk.Checkbutton
@@ -891,8 +958,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 ],
             },
         }
-        if colorname:
-            self._register_style(ttkstyle)
+        self._register_style(ttkstyle)
 
     def create_link_button_style(self, settings, colorname=None):
         """Create a link button style for the ttk.Button widget."""
@@ -961,8 +1027,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 ],
             },
         }
-        if colorname:
-            self._register_style(ttkstyle)
+        self._register_style(ttkstyle)
 
     def create_entry_style(self, settings, colorname=None):
         """Create a style for the ttk.Entry widget."""
@@ -1105,11 +1170,11 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
 
         if any([colorname is None, not colorname]):
             ttkstyle = STYLE
-            element = f"{ttkstyle.replace('TC','C')}"
+            element = f"{ttkstyle.replace('TC', 'C')}"
             focuscolor = self.colors.primary
         else:
             ttkstyle = f"{colorname}.{STYLE}"
-            element = f"{ttkstyle.replace('TC','C')}"
+            element = f"{ttkstyle.replace('TC', 'C')}"
             focuscolor = self.colors.get_color(colorname)
 
         if all([colorname, colorname is not None]):
@@ -1363,10 +1428,12 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
 
         if any([colorname is None, not colorname]):
             background = self.colors.primary
+            foreground = self.colors.fg
             h_ttkstyle = H_STYLE
             v_ttkstyle = V_STYLE
         else:
             background = self.colors.get_color(colorname)
+            foreground = self.colors.get_color(colorname)
             h_ttkstyle = f"{colorname}.{H_STYLE}"
             v_ttkstyle = f"{colorname}.{V_STYLE}"
 
@@ -1374,6 +1441,8 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
         h_element = h_ttkstyle.replace(".TP", ".P")
         htrough_element = f"{h_element}.trough"
         hpbar_element = f"{h_element}.pbar"
+        hpbar_text_element = f"{h_element}.ctext"
+
         if htrough_element not in self.existing_elements:
             settings[htrough_element] = {
                 "element create": ("from", TTK_CLAM),
@@ -1392,6 +1461,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 "pbarrelief": tk.FLAT,
                 "troughcolor": troughcolor,
                 "background": background,
+                "foreground": foreground,
             },
             "layout": [
                 (
@@ -1405,11 +1475,16 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 )
             ],
         }
+        if has_tk_version_9:
+            children = settings[h_ttkstyle]["layout"][0][1]["children"]
+            pbar_text = (hpbar_text_element, {"side": "left", "sticky": ""})
+            children.append(pbar_text)
 
         # vertical progressbar
         v_element = v_ttkstyle.replace(".TP", ".P")
         vtrough_element = f"{v_element}.trough"
         vpbar_element = f"{v_element}.pbar"
+        # vpbar_text_element = f"{v_element}.ctext"
         if vtrough_element not in self.existing_elements:
             settings[vtrough_element] = {
                 "element create": ("from", TTK_CLAM),
@@ -1441,6 +1516,10 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 )
             ],
         }
+        # if has_tk_version_9:
+        #     children = settings[h_ttkstyle]["layout"][0][1]["children"]
+        #     pbar_text = (vpbar_text_element, {"side": "top", "sticky": ""})
+        #     children.append(pbar_text)
         if colorname:
             self._register_style(h_ttkstyle)
             self._register_style(v_ttkstyle)
@@ -2186,9 +2265,8 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 )
             ],
         }
-        if colorname:
-            self._register_style(h_ttkstyle)
-            self._register_style(v_ttkstyle)
+        self._register_style(h_ttkstyle)
+        self._register_style(v_ttkstyle)
 
     def create_square_toggle_style(self, settings, colorname=None):
         """Create a square toggle style for the ttk.Checkbutton widget.
@@ -2270,8 +2348,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 ],
             },
         }
-        if colorname:
-            self._register_style(ttkstyle)
+        self._register_style(ttkstyle)
 
     def create_round_toggle_style(self, settings, colorname=None):
         """Create a round toggle style for the ttk.Checkbutton widget.
@@ -2356,8 +2433,7 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 )
             ],
         }
-        if colorname:
-            self._register_style(ttkstyle)
+        self._register_style(ttkstyle)
 
     def create_round_scrollbar_style(self, settings, colorname=None):
         """Create a round style for the ttk.Scrollbar widget.
@@ -2619,5 +2695,162 @@ if { [info exists ::tk::dialog::file::pbs_hack ] == 1 } {
                 )
             ],
         }
+        self._register_style(body_style)
+
+    def create_floodgauge_style(self, settings, colorname=None):
+        """Create a ttk style for the pygubu Floodgauge
+        widget. This is a custom widget style that uses components of
+        the progressbar and label.
+        """
+        HSTYLE = "Horizontal.TFloodgauge"
+        VSTYLE = "Vertical.TFloodgauge"
+        FLOOD_FONT = "-size 14"
+
+        if any([colorname is None, colorname == ""]):
+            h_ttkstyle = HSTYLE
+            v_ttkstyle = VSTYLE
+            background = self.colors.primary
+        else:
+            h_ttkstyle = f"{colorname}.{HSTYLE}"
+            v_ttkstyle = f"{colorname}.{VSTYLE}"
+            background = self.colors.get_color(colorname)
+
+        if colorname == LIGHT:
+            foreground = self.colors.fg
+            troughcolor = self.colors.bg
+        else:
+            troughcolor = self.colorutil.update_hsv(background, sd=-0.3, vd=0.8)
+            foreground = self.colors.selectfg
+
+        # horizontal floodgauge
+        h_element = h_ttkstyle.replace(".TF", ".F")
+        # vertical floodgauge
+        v_element = v_ttkstyle.replace(".TF", ".F")
+
+        ttk_elements = (
+            (f"{h_element}.trough", TTK_CLAM),
+            (f"{h_element}.pbar", TTK_DEFAULT),
+            (f"{v_element}.trough", TTK_CLAM),
+            (f"{v_element}.pbar", TTK_DEFAULT),
+        )
+        for element_name, from_ in ttk_elements:
+            settings[element_name] = {
+                "element create": ("from", from_),
+            }
+
+        h_layout = None
+        v_layout = None
+        if tk.TkVersion >= 9:
+            h_layout, v_layout = self.floodgauge_layout_tk9(
+                h_element, v_element
+            )
+        else:
+            h_layout, v_layout = self.floodgauge_layout_tk8(
+                h_element, v_element
+            )
+
+        settings[h_ttkstyle] = {
+            "configure": dict(
+                thickness=50,
+                borderwidth=1,
+                bordercolor=background,
+                lightcolor=background,
+                pbarrelief=tk.FLAT,
+                troughcolor=troughcolor,
+                background=background,
+                foreground=foreground,
+                justify=tk.CENTER,
+                anchor=tk.CENTER,
+                font=FLOOD_FONT,
+            ),
+            "layout": h_layout,
+        }
+        settings[v_ttkstyle] = {
+            "configure": dict(
+                thickness=50,
+                borderwidth=1,
+                bordercolor=background,
+                lightcolor=background,
+                pbarrelief=tk.FLAT,
+                troughcolor=troughcolor,
+                background=background,
+                foreground=foreground,
+                justify=tk.CENTER,
+                anchor=tk.CENTER,
+                font=FLOOD_FONT,
+            ),
+            "layout": v_layout,
+        }
+
         if colorname:
-            self._register_style(body_style)
+            self._register_style(h_ttkstyle)
+            self._register_style(v_ttkstyle)
+
+    def floodgauge_layout_tk9(self, h_element: str, v_element: str) -> tuple:
+        h_layout = [
+            (
+                f"{h_element}.trough",
+                {
+                    "children": [
+                        (f"{h_element}.pbar", {"side": "left", "sticky": "ns"}),
+                        (
+                            f"{h_element}.ctext",
+                            # {"side": "left", "sticky": ""}
+                            {"side": "left", "sticky": "", "expand": True},
+                        ),
+                    ],
+                    "sticky": "nswe",
+                },
+            )
+        ]
+
+        v_layout = [
+            (
+                f"{v_element}.trough",
+                {
+                    "children": [
+                        (
+                            f"{v_element}.pbar",
+                            {"side": "bottom", "sticky": "we"},
+                        ),
+                        (f"{v_element}.ctext", {"sticky": "", "expand": True}),
+                    ],
+                    "sticky": "nswe",
+                },
+            )
+        ]
+        return h_layout, v_layout
+
+    def floodgauge_layout_tk8(self, h_element: str, v_element: str) -> tuple:
+        TKCLASS_NAME = "Floodgauge"
+        h_layout = [
+            (
+                f"{h_element}.trough",
+                {
+                    "children": [
+                        (
+                            f"{h_element}.pbar",
+                            {"sticky": "ns"},
+                        ),
+                        (f"{TKCLASS_NAME}.label", {"sticky": ""}),
+                    ],
+                    "sticky": "nsew",
+                },
+            )
+        ]
+        v_layout = [
+            (
+                f"{v_element}.trough",
+                {
+                    "children": [
+                        (
+                            f"{v_element}.pbar",
+                            {"sticky": "ew"},
+                        ),
+                        (f"{TKCLASS_NAME}.label", {"sticky": ""}),
+                    ],
+                    "sticky": "nsew",
+                },
+            )
+        ]
+        return h_layout, v_layout
